<TS language="la" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Crea novam inscriptionem</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copia inscriptionem iam selectam in latibulum systematis</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Dele active selectam inscriptionem ex enumeratione</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Dele</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copia &amp;Titulum</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Muta</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Titulus</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Inscriptio</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nullus titulus)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialogus Tesserae</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Insere tesseram</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova tessera</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Itera novam tesseram</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Cifra cassidile</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Huic operationi necesse est tessera cassidili tuo ut cassidile reseret.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Resera cassidile</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Muta tesseram</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Insero veterem novamque tesseram cassidili.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirma cifrationem cassidilis</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Certusne es te velle tuum cassidile cifrare?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Cassidile cifratum</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>GRAVE: Oportet ulla prioria conservata quae fecisti de plica tui cassidilis reponi a nove generata cifrata plica cassidilis.  Propter securitatem, prioria conservata de plica non cifrata cassidilis inutilia fiet simul atque incipis uti novo cifrato cassidili.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Cassidile cifrare abortum est</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Cassidile cifrare abortum est propter internum errorem.  Tuum cassidile cifratum non est.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Tesserae datae non eaedem sunt.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Cassidile reserare abortum est.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Tessera inserta pro cassidilis decifrando prava erat.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Tessera cassidilis successa est in mutando.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Monitio: Litterae ut capitales seratae sunt!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Cassidile</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Summarium</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Monstra generale summarium cassidilis</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Mitte</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Accipe</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Inspicio historiam transactionum</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>E&amp;xi</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Exi applicatione</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Optiones</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Monstra/Occulta</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Cifra Cassidile...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Muta tesseram...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Muta tesseram utam pro cassidilis cifrando</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Signa &amp;nuntium...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifica nuntium...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Fenestra &amp;Debug</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Aperi terminalem debug et diagnosticalem</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Plica</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuratio</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Auxilium</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Recentissimo</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Persequens...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transactio missa</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transactio incipiens</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Cassidile &lt;b&gt;cifratum&lt;/b&gt; est et iam nunc &lt;b&gt;seratum&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Monitio Retis</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Quantitas:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantitas</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dies</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmatum</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Inscriptio</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copia inscriptionem</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copia titulum</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia quantitatem</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copia transactionis ID</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nullus titulus)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Muta Inscriptionem</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Titulus</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Inscriptio</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nova inscriptio accipiendi</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nova inscriptio mittendi</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Muta inscriptionem accipiendi</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Muta inscriptionem mittendi</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Inserta inscriptio "%1" iam in libro inscriptionum est.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Non potuisse cassidile reserare</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Generare novam clavem abortum est.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Optiones</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Princeps</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Rete</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Designa portam utendo &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Porta:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Porta vicarii (e.g. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minifac potius quam exire applicatione quando fenestra clausa sit.  Si haec optio activa est, applicatio clausa erit tantum postquam selegeris Exi in menu.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Monstra inscriptiones in enumeratione transactionum</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenestra</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Monstra tantum iconem in tabella systematis postquam fenestram minifactam est.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minifac in tabellam systematis potius quam applicationum</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inifac ad claudendum</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;UI</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Lingua monstranda utenti:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unita qua quantitates monstrare:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Selige praedefinitam unitam subdivisionis monstrare in interfacie et quando nummos mittere</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancella</translation>
    </message>
    <message>
        <source>default</source>
        <translation>praedefinitum</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Inscriptio vicarii tradita non valida est.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Schema</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Immatura:</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Versio clientis</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informatio</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Tempus initiandi</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Numerus conexionum</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Catena frustorum</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Numerus frustorum iam nunc</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Hora postremi frusti</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Aperi</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Terminale</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Debug catalogi plica</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Vacuefac terminale</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Aestimatus totalis numerus frustorum</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nomen clientis</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Utere sagittis sursum deorsumque ut per historiam naviges, et &lt;b&gt;Ctrl+L&lt;/b&gt; ut scrinium vacuefacias.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Scribe &lt;b&gt;help&lt;/b&gt; pro summario possibilium mandatorum.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Mitte Nummos</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Inopia nummorum</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Quantitas:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Mitte pluribus accipientibus simul</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Adde &amp;Accipientem</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Vacuefac &amp;Omnia</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirma actionem mittendi</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Mitte</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia quantitatem</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirma mittendum nummorum</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Inscriptio accipientis non est valida, sodes reproba.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Oportet quantitatem ad pensandum maiorem quam 0 esse.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Quantitas est ultra quod habes.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Quantitas est ultra quod habes cum merces transactionis %1 includitur.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Geminata inscriptio inventa, tantum posse mittere ad quamque inscriptionem semel singulare operatione.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nullus titulus)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Quantitas:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Pensa &amp;Ad:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Nuntius:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Titulus:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Glutina inscriptionem ex latibulo</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Insero titulum huic inscriptioni ut eam in tuum librum inscriptionum addas.</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Signationes - Signa / Verifica nuntium</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Signa Nuntium</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Potes nuntios signare inscriptionibus tuis ut demonstres te eas possidere.  Cautus es non amibiguum signare, quia impetus phiscatorum conentur te fallere ut signes identitatem tuam ad eos.  Solas signa sententias cuncte descriptas quibus convenis.</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Glutina inscriptionem ex latibulo</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Insere hic nuntium quod vis signare</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copia signationem in latibulum systematis</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Signa &amp;Nuntium</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Reconstitue omnes campos signandi nuntii</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Vacuefac &amp;Omnia</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifica Nuntium</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Insere inscriptionem signantem, nuntium (cura ut copias intermissiones linearum, spatia, tabs, et cetera exacte) et signationem infra ut nuntium verifices.  Cautus esto ne magis legas in signationem quam in nuntio signato ipso est, ut vites falli ab impetu homo-in-medio.</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Reconstitue omnes campos verificandi nuntii</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Clicca "Signa Nuntium" ut signatio generetur</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Inscriptio inserta non valida est.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Sodes inscriptionem proba et rursus conare.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Inserta inscriptio clavem non refert.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Cassidilis reserare cancellatum est.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Clavis privata absens est pro inserta inscriptione.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Nuntium signare abortum est.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Nuntius signatus.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Signatio decodificari non potuit.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Sodes signationem proba et rursus conare.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Signatio non convenit digesto nuntii</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Nuntium verificare abortum est.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Nuntius verificatus.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Apertum donec %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/non conecto</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/non confirmata</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 confirmationes</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, nondum prospere disseminatum est</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dies</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fons</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Ab</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ignotum</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Ad</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>inscriptio propria</translation>
    </message>
    <message>
        <source>label</source>
        <translation>titulus</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Creditum</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>non acceptum</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debitum</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transactionis merces</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Cuncta quantitas</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Nuntius</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Annotatio</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantitas</translation>
    </message>
    <message>
        <source>true</source>
        <translation>verum</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falsum</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Particularia transactionis</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Haec tabula monstrat descriptionem verbosam transactionis</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dies</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typus</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Inscriptio</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantitas</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Apertum donec %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confirmatum (%1 confirmationes)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generatum sed non acceptum</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Acceptum cum</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Acceptum ab</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Missum ad</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pensitatio ad te ipsum</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Status transactionis.  Supervola cum mure ut monstretur numerus confirmationum.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Dies et tempus quando transactio accepta est.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Typus transactionis.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Inscriptio destinationis transactionis.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Quantitas remota ex pendendo aut addita ei.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Hodie</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Hac hebdomade</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Hoc mense</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Postremo mense</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Hoc anno</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Intervallum...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Acceptum cum</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Missum ad</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Ad te ipsum</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Fossa</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Alia</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Quantitas minima</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copia inscriptionem</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copia titulum</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia quantitatem</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copia transactionis ID</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Muta titulum</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Monstra particularia transactionis</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmatum</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dies</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typus</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Titulus</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Inscriptio</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantitas</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Intervallum:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>ad</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Error erat dum initians portam RPC %u pro auscultando in IPv6, labens retrorsum ad IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Error erat dum initians portam RPC %u pro auscultando in IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Usus:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Enumera mandata</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Accipe auxilium pro mandato</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Monitio: -paytxfee constitutum valde magnum!  Hoc est merces transactionis solves si mittis transactionem.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Monitio: wallet.data corrupta, data salvata!  Originalis wallet.dat salvata ut wallet.{timestamp}.bak in %s; si pendendum tuum vel transactiones pravae sunt, oportet ab conservato restituere.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Monitio: error legendo wallet.dat!  Omnes claves recte lectae, sed data transactionum vel libri inscriptionum fortasse desint vel prava sint.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Non potuisse auscultare in ulla porta.  Utere -listen=0 si hoc vis.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Ut utaris optione %s</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Necesse est te rpcpassword=&lt;tesseram&gt; constituere in plica configurationum:
%s
Si plica non existat, crea eam cum permissionibus ut solus eius dominus eam legere sinatur.</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Quantitas non valida pro -paytxfee=&lt;quantitas&gt;: '%s'</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat corrupta, salvare abortum est</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Inscriptio -proxy non valida: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Non posse resolvere -bind inscriptonem: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Non posse resolvere -externalip inscriptionem: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Error legendi wallet.dat: Cassidile corruptum</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Error legendi wallet.dat</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Legens inscriptiones...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Non posse conglutinare ad %s in hoc computatro (conglutinare redidit errorem %d, %s)</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Quantitas non valida</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Ignotum rete specificatum in -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Inopia nummorum</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Legens indicem frustorum...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Legens cassidile...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Non posse scribere praedefinitam inscriptionem</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Iterum perlegens...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Completo lengendi</translation>
    </message>
    </context>
</TS>